@@ -52,7 +52,7 @@ extern RpcResult_t IPC_InitIprpc(RpcBool_t masterProcess, RpcBool_t useSkelton,
 	RpcResult_t ret = RPC_SUCCESS;
 
 	/* INIT LOG SYSTEM */
-//	(void)RPC_LogPrint(RPC_LOG_MODULE_LIB,RPC_LOG_LEVEL_DEBUG1,"IN RPC_InitIpc PID:0x%x; master:%d; useSkelton:%d; useStub:%d;",RPC_GetPid(),masterProcess, useSkelton, useStub);
+//	(void)RPC_LogPrint(RPC_LOG_MODULE_INIT,RPC_LOG_LEVEL_DEBUG1,"IN RPC_InitIpc PID:0x%x; master:%d; useSkelton:%d; useStub:%d;",RPC_GetPid(),masterProcess, useSkelton, useStub);
 	if((ret = RPC_LogInit()) != RPC_SUCCESS) {
 		return ret;
 	}
@@ -62,70 +62,70 @@ extern RpcResult_t IPC_InitIprpc(RpcBool_t masterProcess, RpcBool_t useSkelton,
 	}
 #else	/*  */
 	if((ret = RPC_LogSetAll(RPC_LOG_LEVEL_DEBUG3)) != RPC_SUCCESS) {
-		(void)RPC_LogPrint(RPC_LOG_MODULE_LIB,RPC_LOG_LEVEL_FATAL,"ERROR IN RpcLogSetAll ret:0x%x;",ret);
+		(void)RPC_LogPrint(RPC_LOG_MODULE_INIT,RPC_LOG_LEVEL_FATAL,"ERROR IN RpcLogSetAll ret:0x%x;",ret);
 		return 1;
 	}
 #endif	/*  */
 	/* INIT SHM */
 	if((ret = IPC_InitSharedMem(masterProcess)) != RPC_SUCCESS) {
-		(void)RPC_LogPrint(RPC_LOG_MODULE_LIB, RPC_LOG_LEVEL_FATAL, "FATAL ERROR in IPC_InitSharedMem RET:%s;",RPC_LogConvertResultCode(ret));
+		(void)RPC_LogPrint(RPC_LOG_MODULE_INIT, RPC_LOG_LEVEL_FATAL, "FATAL ERROR in IPC_InitSharedMem RET:%s;",RPC_LogConvertResultCode(ret));
 		return ret;
 	}
 	if((ret = IPC_AttachSharedMem()) != RPC_SUCCESS) {
-		(void)RPC_LogPrint(RPC_LOG_MODULE_LIB, RPC_LOG_LEVEL_FATAL, "FATAL ERROR in IPC_AttachSharedMem RET:%s;",RPC_LogConvertResultCode(ret));
+		(void)RPC_LogPrint(RPC_LOG_MODULE_INIT, RPC_LOG_LEVEL_FATAL, "FATAL ERROR in IPC_AttachSharedMem RET:%s;",RPC_LogConvertResultCode(ret));
 		goto goError0;
 	}
 	/* INIT SHM DB */
 	if((ret = IPC_InitShmDB(masterProcess)) != RPC_SUCCESS) {
-		(void)RPC_LogPrint(RPC_LOG_MODULE_LIB, RPC_LOG_LEVEL_FATAL, "FATAL ERROR in IPC_InitShmDB RET:%s;",RPC_LogConvertResultCode(ret));
+		(void)RPC_LogPrint(RPC_LOG_MODULE_INIT, RPC_LOG_LEVEL_FATAL, "FATAL ERROR in IPC_InitShmDB RET:%s;",RPC_LogConvertResultCode(ret));
 		goto goError1;
 	}
 //	printFixedAreaList(0x4);
 //	printFreeAreaLIst(0x4);
 	/* INIT QUE SYSTEM */
 	if((ret = IPC_InitQue(masterProcess,RPC_TRUE)) != RPC_SUCCESS) {
-		(void)RPC_LogPrint(RPC_LOG_MODULE_LIB, RPC_LOG_LEVEL_FATAL, "FATAL ERROR in IPC_InitQue - EXTERNAL RET:%s;",RPC_LogConvertResultCode(ret));
+		(void)RPC_LogPrint(RPC_LOG_MODULE_INIT, RPC_LOG_LEVEL_FATAL, "FATAL ERROR in IPC_InitQue - EXTERNAL RET:%s;",RPC_LogConvertResultCode(ret));
 		goto goError1;
 	}
 	if((ret = IPC_InitQue(masterProcess,RPC_FALSE)) != RPC_SUCCESS) {
-		(void)RPC_LogPrint(RPC_LOG_MODULE_LIB, RPC_LOG_LEVEL_FATAL, "FATAL ERROR in IPC_InitQue - INTERNAL RET:%s;",RPC_LogConvertResultCode(ret));
+		(void)RPC_LogPrint(RPC_LOG_MODULE_INIT, RPC_LOG_LEVEL_FATAL, "FATAL ERROR in IPC_InitQue - INTERNAL RET:%s;",RPC_LogConvertResultCode(ret));
 		goto goError1;
 	}
 	/* INIT MARSHAL LIBRARY */
 	if((ret = IPC_InitMarshal(masterProcess)) != RPC_SUCCESS) {
-		(void)RPC_LogPrint(RPC_LOG_MODULE_LIB,RPC_LOG_LEVEL_FATAL,"ERROR IN IPC_InitMarshal RET:%s;",RPC_LogConvertResultCode(ret));
+		(void)RPC_LogPrint(RPC_LOG_MODULE_INIT,RPC_LOG_LEVEL_FATAL,"ERROR IN IPC_InitMarshal RET:%s;",RPC_LogConvertResultCode(ret));
 		goto goError1;	
 	}
 	/* INIT SKELTON */
 	if(useSkelton) {
-//		(void)RPC_LogPrint(RPC_LOG_MODULE_LIB,RPC_LOG_LEVEL_DEBUG1,"NOW CALL IPC_InitSkelton PID:0x%x;",RPC_GetPid());
+//		(void)RPC_LogPrint(RPC_LOG_MODULE_INIT,RPC_LOG_LEVEL_DEBUG1,"NOW CALL IPC_InitSkelton PID:0x%x;",RPC_GetPid());
 		if((ret = IPC_InitSkelton(masterProcess)) != RPC_SUCCESS) {
-			(void)RPC_LogPrint(RPC_LOG_MODULE_LIB,RPC_LOG_LEVEL_FATAL,"ERROR IN IPC_InitSkelton RET:%s;",RPC_LogConvertResultCode(ret));
+			(void)RPC_LogPrint(RPC_LOG_MODULE_INIT,RPC_LOG_LEVEL_FATAL,"ERROR IN IPC_InitSkelton RET:%s;",RPC_LogConvertResultCode(ret));
 			goto goError1;			
 		}
-//		(void)RPC_LogPrint(RPC_LOG_MODULE_LIB,RPC_LOG_LEVEL_DEBUG1,"END CALL IPC_InitSkelton PID:0x%x;",RPC_GetPid());
+//		(void)RPC_LogPrint(RPC_LOG_MODULE_INIT,RPC_LOG_LEVEL_DEBUG1,"END CALL IPC_InitSkelton PID:0x%x;",RPC_GetPid());
 	}
 	else {
-//		(void)RPC_LogPrint(RPC_LOG_MODULE_LIB,RPC_LOG_LEVEL_DEBUG1,"NOT CALL IPC_InitSkelton AS useSkelton:%d; PID:0x%x;",useSkelton, RPC_GetPid());
+//		(void)RPC_LogPrint(RPC_LOG_MODULE_INIT,RPC_LOG_LEVEL_DEBUG1,"NOT CALL IPC_InitSkelton AS useSkelton:%d; PID:0x%x;",useSkelton, RPC_GetPid());
 	}
 	/* INIT STUB */
 	if(useStub) {
 		if((ret = IPC_InitStub(masterProcess)) != RPC_SUCCESS) {
-			(void)RPC_LogPrint(RPC_LOG_MODULE_LIB,RPC_LOG_LEVEL_FATAL,"ERROR IN IPC_InitStub RET:%s;",RPC_LogConvertResultCode(ret));
+			(void)RPC_LogPrint(RPC_LOG_MODULE_INIT,RPC_LOG_LEVEL_FATAL,"ERROR IN IPC_InitStub RET:%s;",RPC_LogConvertResultCode(ret));
 			goto goError1;					
 		}
 	}
 	else {
-//		(void)RPC_LogPrint(RPC_LOG_MODULE_LIB,RPC_LOG_LEVEL_DEBUG1,"NOT CALL IPC_InitStub AS useStub:%d; PID:0x%x;",useStub, RPC_GetPid());
+//		(void)RPC_LogPrint(RPC_LOG_MODULE_INIT,RPC_LOG_LEVEL_DEBUG1,"NOT CALL IPC_InitStub AS useStub:%d; PID:0x%x;",useStub, RPC_GetPid());
 	}
 #ifdef	USE_RENDEZVOUS
 	if((ret = IPC_InitRendezv(masterProcess)) != RPC_SUCCESS) {
-		(void)RPC_LogPrint(RPC_LOG_MODULE_LIB,RPC_LOG_LEVEL_FATAL,"ERROR IN IPC_InitRendezv RET:%s;",RPC_LogConvertResultCode(ret));
+		(void)RPC_LogPrint(RPC_LOG_MODULE_INIT,RPC_LOG_LEVEL_FATAL,"ERROR IN IPC_InitRendezv RET:%s;",RPC_LogConvertResultCode(ret));
 		goto goError1;
 	}
 #endif	/* USE_RENDEZVOUS */
 //	IPC_PrintQueData();
-//	(void)RPC_LogPrint(RPC_LOG_MODULE_LIB,RPC_LOG_LEVEL_DEBUG1,"OUT IPC_InitIpc PID:0x%x;",RPC_GetPid());
+//	(void)RPC_LogPrint(RPC_LOG_MODULE_INIT,RPC_LOG_LEVEL_DEBUG1,"OUT IPC_InitIpc PID:0x%x;",RPC_GetPid());
 	return ret;
 
 goError1:
