@@ -99,6 +99,7 @@ extern RpcResult_t RPC_CreateTaskControl(RpcBool_t IpcFlag,RpcTaskControl_t *tsk
 		return ret;
 	}
 	tskCntl->cntlSignal = RPC_FALSE;
+	tskCntl->inWaitTask = RPC_FALSE;
 #else	/* USE_SEMAPHORE */
 	if((ret = RPC_SemInit(&(tskCntl->semId),IpcFlag?IPC_TACK_CNTL_SEM_SHARED:IPC_TACK_CNTL_SEM_PRIVATE,IPC_TACK_CNTL_SEM_INIT_NUM)) != RPC_SUCCESS) {
 		return ret;		
@@ -121,10 +122,11 @@ extern void RPC_DestroyTaskControl(RpcTaskControl_t *tskCntl) {
 extern RpcResult_t RPC_TaskControlWait(RpcTaskControl_t *tskCntl) {
 	RpcResult_t ret;
 
-//	(void)RPC_LogPrint(RPC_LOG_MODULE_LIB,RPC_LOG_LEVEL_DEBUG2,"IN RPC_TaskControlWait");
 	if(tskCntl == (RpcTaskControl_t*)NULL)
 		return RPC_PARAM_ERROR;
 #ifndef	USE_SEMAPHORE
+//	(void)RPC_LogPrint(RPC_LOG_MODULE_LIB,RPC_LOG_LEVEL_DEBUG2,"IN RPC_TaskControlWait tskCntl:0x%Lx; inWaitTask:%d; cntlSignal:%d;",
+//	tskCntl,tskCntl->inWaitTask,tskCntl->cntlSignal);
 	if((ret = RPC_MutexLock(&(tskCntl->mutexId))) != RPC_SUCCESS) {
 		(void)RPC_LogPrint(RPC_LOG_MODULE_LIB,RPC_LOG_LEVEL_FATAL, " ERROR in RPC_MutexLock ret:%s",RPC_LogConvertResultCode(ret));
 		return ret;			
@@ -132,25 +134,34 @@ extern RpcResult_t RPC_TaskControlWait(RpcTaskControl_t *tskCntl) {
 #ifdef	USE_CANCEL_TASK
 	RPC_TaskPushCleanup(RPC_taskCntlCleanup,(void*)tskCntl);
 #endif	/* USE_CANCEL_TASK */
-	while(!(tskCntl->cntlSignal)) {
+	if(tskCntl->inWaitTask) {
+		(void)RPC_LogPrint(RPC_LOG_MODULE_LIB,RPC_LOG_LEVEL_ERROR,"A Task Is Already Waiting A Signal");
+		(void)RPC_MutexUnlock(&(tskCntl->mutexId));
+		return RPC_BUSY_ERROR;
+	}
+	tskCntl->inWaitTask = RPC_TRUE;
+	if(!(tskCntl->cntlSignal)) {
 		if((ret = RPC_CondWait(&(tskCntl->condId),&(tskCntl->mutexId))) != RPC_SUCCESS) {
+			tskCntl->inWaitTask = RPC_FALSE;
 			(void)RPC_LogPrint(RPC_LOG_MODULE_LIB,RPC_LOG_LEVEL_FATAL, " ERROR in RPC_CondWait ret:%s",RPC_LogConvertResultCode(ret));
 			(void)RPC_MutexUnlock(&(tskCntl->mutexId));
 			return ret;
 		}
 	}
 	tskCntl->cntlSignal = RPC_FALSE;
+	tskCntl->inWaitTask = RPC_FALSE;
 #ifdef	USE_CANCEL_TASK
 	RPC_TaskPopCleanup(0);
 #endif	/* USE_CANCEL_TASK */
 	(void)RPC_MutexUnlock(&(tskCntl->mutexId));
+//	(void)RPC_LogPrint(RPC_LOG_MODULE_LIB,RPC_LOG_LEVEL_DEBUG2,"OUT RPC_TaskControlWait tskCntl:0x%Lx; inWaitTask:%d; cntlSignal:%d;",
+//	tskCntl,tskCntl->inWaitTask,tskCntl->cntlSignal);
 #else	/* USE_SEMAPHORE */
 	if((ret = RPC_SemWait(&(tskCntl->semId))) != RPC_SUCCESS) {
 		(void)RPC_LogPrint(RPC_LOG_MODULE_LIB,RPC_LOG_LEVEL_FATAL, " ERROR in RPC_SemWait ret:%s",RPC_LogConvertResultCode(ret));
 		return ret;						
 	}
 #endif	/* USE_SEMAPHORE */
-//	(void)RPC_LogPrint(RPC_LOG_MODULE_LIB,RPC_LOG_LEVEL_DEBUG2,"OUT RPC_TaskControlWait");
 	return RPC_SUCCESS;
 }
 
@@ -168,8 +179,15 @@ extern RpcResult_t RPC_TaskControlTimedWait(RpcTaskControl_t *tskCntl, struct ti
 #ifdef	USE_CANCEL_TASK
 	RPC_TaskPushCleanup(RPC_taskCntlCleanup,(void*)tskCntl);
 #endif	/* USE_CANCEL_TASK */
-	while(!(tskCntl->cntlSignal)) {
+	if(tskCntl->inWaitTask) {
+		(void)RPC_LogPrint(RPC_LOG_MODULE_LIB,RPC_LOG_LEVEL_ERROR,"Already Waiting A Task");
+		(void)RPC_MutexUnlock(&(tskCntl->mutexId));
+		return RPC_BUSY_ERROR;
+	}
+	tskCntl->inWaitTask = RPC_TRUE;
+	if(!(tskCntl->cntlSignal)) {
 		if((ret = RPC_CondWaitTimeout(&(tskCntl->condId),&(tskCntl->mutexId),specTime)) != RPC_SUCCESS) {
+			tskCntl->inWaitTask = RPC_FALSE;
 			if(ret == RPC_TIMEOUT_ERROR)
 				(void)RPC_LogPrint(RPC_LOG_MODULE_LIB,RPC_LOG_LEVEL_WARNING, " TIMEOUT in RPC_CondWaitTimeout ret:%s",RPC_LogConvertResultCode(ret));
 			else
@@ -179,6 +197,7 @@ extern RpcResult_t RPC_TaskControlTimedWait(RpcTaskControl_t *tskCntl, struct ti
 		}
 	}
 	tskCntl->cntlSignal = RPC_FALSE;
+	tskCntl->inWaitTask = RPC_FALSE;
 #ifdef	USE_CANCEL_TASK
 	RPC_TaskPopCleanup(0);
 #endif	/* USE_CANCEL_TASK */
@@ -199,11 +218,12 @@ extern RpcResult_t RPC_TaskControlTimedWait(RpcTaskControl_t *tskCntl, struct ti
 extern RpcResult_t RPC_TaskControlSignal(RpcTaskControl_t *tskCntl) {
 	RpcResult_t ret;
 
-//	(void)RPC_LogPrint(RPC_LOG_MODULE_LIB,RPC_LOG_LEVEL_DEBUG2,"IN RPC_TaskControlSignal");
 	if(tskCntl == (RpcTaskControl_t*)NULL)
 		return RPC_PARAM_ERROR;
 #ifndef	USE_SEMAPHORE
-#if	0
+//	(void)RPC_LogPrint(RPC_LOG_MODULE_LIB,RPC_LOG_LEVEL_DEBUG2,"IN RPC_TaskControlSignal tskCntl:0x%Lx; inWaitTask:%d; cntlSignal:%d;",
+//	tskCntl,tskCntl->inWaitTask,tskCntl->cntlSignal);
+#if	1
 	if((ret = RPC_MutexLock(&(tskCntl->mutexId))) != RPC_SUCCESS) {
 		(void)RPC_LogPrint(RPC_LOG_MODULE_LIB,RPC_LOG_LEVEL_FATAL, " ERROR in RPC_MutexLock ret:%s",RPC_LogConvertResultCode(ret));
 		return ret;
@@ -215,33 +235,42 @@ extern RpcResult_t RPC_TaskControlSignal(RpcTaskControl_t *tskCntl) {
 		return ret;
 	}
 	(void)RPC_MutexUnlock(&(tskCntl->mutexId));
-#else	/* 0 */
+#else	/* 1 */
 	tskCntl->cntlSignal = RPC_TRUE;
 	if((ret = RPC_CondSignal(&(tskCntl->condId))) != RPC_SUCCESS) {
 		(void)RPC_LogPrint(RPC_LOG_MODULE_LIB,RPC_LOG_LEVEL_FATAL, " ERROR in RPC_CondSignal ret:%s",RPC_LogConvertResultCode(ret));
 		return ret;
 	}
-#endif	/* 0 */
+#endif	/* 1 */
+//	(void)RPC_LogPrint(RPC_LOG_MODULE_LIB,RPC_LOG_LEVEL_DEBUG2,"OUT RPC_TaskControlSignal tskCntl:0x%Lx; inWaitTask:%d; cntlSignal:%d;",
+//	tskCntl,tskCntl->inWaitTask,tskCntl->cntlSignal);
 #else	/* USE_SEMAPHORE */
 	if((ret = RPC_SemPost(&(tskCntl->semId))) != RPC_SUCCESS) {
 		(void)RPC_LogPrint(RPC_LOG_MODULE_LIB,RPC_LOG_LEVEL_FATAL, " ERROR in RPC_SemPost ret:%s",RPC_LogConvertResultCode(ret));
 		return ret;
 	}
 #endif	/* USE_SEMAPHORE */
-//	(void)RPC_LogPrint(RPC_LOG_MODULE_LIB,RPC_LOG_LEVEL_DEBUG2,"OUT RPC_TaskControlSignal");
 	return RPC_SUCCESS;
 }
 
 extern void IPC_ResetTaskControl(RpcTaskControl_t *tskCntl) {
 #ifndef	USE_SEMAPHORE
+//	(void)RPC_LogPrint(RPC_LOG_MODULE_LIB,RPC_LOG_LEVEL_DEBUG2,"IN IPC_ResetTaskControl tskCntl:0x%Lx; inWaitTask:%d; cntlSignal:%d;",
+//	tskCntl,tskCntl->inWaitTask,tskCntl->cntlSignal);
 	{RpcResult_t ret;
 	if((ret = RPC_MutexLock(&(tskCntl->mutexId))) != RPC_SUCCESS) {
 		(void)RPC_LogPrint(RPC_LOG_MODULE_LIB,RPC_LOG_LEVEL_FATAL, " ERROR in RPC_MutexLock ret:%s",RPC_LogConvertResultCode(ret));
 		return ;
 	}
+	if(tskCntl->inWaitTask) {
+		(void)RPC_CondSignal(&(tskCntl->condId));
+		tskCntl->inWaitTask = RPC_FALSE;
+	}
 	tskCntl->cntlSignal = RPC_FALSE;
 	(void)RPC_MutexUnlock(&(tskCntl->mutexId));
 	}
+//	(void)RPC_LogPrint(RPC_LOG_MODULE_LIB,RPC_LOG_LEVEL_DEBUG2,"OUT IPC_ResetTaskControl tskCntl:0x%Lx; inWaitTask:%d; cntlSignal:%d;",
+//	tskCntl,tskCntl->inWaitTask,tskCntl->cntlSignal);
 #else	/* USE_SEMAPHORE */
 	if(tskCntl == (RpcTaskControl_t*)NULL)
 		return;
