@@ -40,6 +40,12 @@
 #include	"ipcSyscall.h"
 #include	"ipcShm.h"
 
+typedef struct _RpcListStruct_ {
+	struct _RpcListStruct_ *next;
+//	uint32_t entryId;
+	void *entry;
+} RpcList_t;
+
 typedef struct {
 	void *entry;
 	RpcBool_t usedFlag;
@@ -52,6 +58,7 @@ typedef struct {
 	RpcCondID_t condId;
 	RpcCondAttribute_t condAttr;
 	RpcBool_t cntlSignal;
+	RpcBool_t inWaitTask;
 #else	/* USE_SEMAPHORE */
 	RpcSem_t semId;
 #endif	/* USE_SEMAPHORE */
