@@ -51,9 +51,9 @@
 #define	IPC_ENABLE_UINT_TYPE_LENGTH			0x0000000F
 #ifdef	IEEE754_LONG_DOUBLE_BIAS
 #define	IPC_ENABLE_FLOAT_TYPE_LENGTH			0x0000001C
-#else	/* IEEE854_LONG_DOUBLE_BIAS */
+#else	/* IEEE754_LONG_DOUBLE_BIAS */
 #define	IPC_ENABLE_FLOAT_TYPE_LENGTH			0x0000000C
-#endif	/* IEEE854_LONG_DOUBLE_BIAS */
+#endif	/* IEEE754_LONG_DOUBLE_BIAS */
 #define	IPC_ENABLE_ENUM_TYPE_LENGTH			0x00000004
 #define	IPC_ENABLE_STRING_TYPE_LENGTH			IPC_NO_RESTRICTION_LENGTH
 #define	IPC_ENABLE_OCTET_ARRAY_TYPE_LENGTH		IPC_NO_RESTRICTION_LENGTH
@@ -61,15 +61,25 @@
 #ifndef	USE_IDC
 #define	IPC_ENABLE_REFERENCE_TYPE_LENGTH		0x00000008
 #else	/* USE_IDC */
-#define	IPC_ENABLE_REFERENCE_TYPE_LENGTH		0x00000010
+#define	IPC_ENABLE_REFERENCE_TYPE_LENGTH		0x00000018
 #endif	/* USE_IDC */
 
+#define	IPC_LENGTH_OF_BOOLEAN_TYPE			0x00000001
+#define	IPC_LENGTH_OF_ADDR_OF_REFERENCE_TYPE		0x00000008
+#ifdef	USE_IDC
+#define	IPC_LENGTH_OF_DEVID_OF_REFERENCE_TYPE		0x00000008
+#endif	/* USE_IDC */
+
+#define	IPC_TRUE_VAL_OF_BOOLEAN_TYPE			(1)
+#define	IPC_FALSE_VAL_OF_BOOLEAN_TYPE			(0)
+
 static int32_t IpcMarshalDataSharedMemId = -1;
 
 static RpcResult_t IPC_parseOneData(RpcParamData_t *inData,uint32_t *useSize);
 static RpcResult_t IPC_checkParamLength(uint32_t paramLeng,uint32_t enableLeng);
 static RpcResult_t IPC_putOneData(RpcParamData_t *inData,void *outData,uint32_t outSize,uint32_t *useSize);
 static RpcResult_t IPC_parseMarshaledData(void *inData,uint32_t inSize,uint32_t *needSize,RpcParamData_t *pData);
+static RpcResult_t IPC_putMarshalledData(RpcParamData_t *pData,void *outP,uint32_t *leng);
 
 #ifdef	RPC_CHECK_BYTEORDER
 static void IPC_convertNetworkByteOrder(void *inData,void *outData,uint32_t size);
@@ -161,8 +171,7 @@ extern RpcResult_t IPC_Marshal(RpcParamData_t *inData, void **outData, uint32_t
 
 extern RpcResult_t IPC_Unmarshal(void *inData, uint32_t inSize, void *outData, uint32_t outSize) {
 	RpcParamData_t *pData;void *inP,*outP;int32_t size,needSize,oSize;
-	RpcResult_t ret;RpcParamHeader_t *header;
-	uint32_t temp;
+	RpcResult_t ret;RpcParamHeader_t *header; uint32_t leng;
 
 //	(void)RPC_LogPrint(RPC_LOG_MODULE_MARSHAL,RPC_LOG_LEVEL_DEBUG1,"IN IPC_Unmarshal inData:0x%x; inSize:%d; outData:0x%x; outSize:%d;",
 //		inData, inSize, outData, outSize);
@@ -175,8 +184,8 @@ extern RpcResult_t IPC_Unmarshal(void *inData, uint32_t inSize, void *outData, u
 //	inP = inData; size = inSize;
 	header = (RpcParamHeader_t*)inData;
 #ifdef	RPC_CHECK_BYTEORDER
-	IPC_convertHostByteOrder((void*)&(header->paramLength),(void*)&temp,sizeof(header->paramLength));
-	header->paramLength = temp;
+	IPC_convertHostByteOrder((void*)&(header->paramLength),(void*)&leng,sizeof(header->paramLength));
+	header->paramLength = leng;
 #endif	/* RPC_CHECK_BYTEORDER */
 	if(header->paramLength != inSize) {
 		return RPC_PARAM_ERROR;
@@ -214,41 +223,17 @@ extern RpcResult_t IPC_Unmarshal(void *inData, uint32_t inSize, void *outData, u
 		if(oSize < IPC_ALIGNMENT(pData->paramSpec.paramLeng)) {
 			return RPC_NO_MORE_RESOURCE;
 		}
-#ifndef	RPC_CHECK_BYTEORDER
-		(void)memcpy(outP,pData->paramData,pData->paramSpec.paramLeng);
-#else	/* RPC_CHECK_BYTEORDER */
-		switch(pData->paramSpec.paramType) {
-		case RPC_INT_TYPE:
-		case RPC_UINT_TYPE:
-		case RPC_ENUM_TYPE:
-		case RPC_BOOLEAN_TYPE:
-		case RPC_FLOAT_TYPE:
-		case RPC_REFERENCE_TYPE:
-			IPC_convertHostByteOrder((void*)pData->paramData,(void*)outP,pData->paramSpec.paramLeng);
-			temp = pData->paramSpec.paramLeng;
-			break;
-		case RPC_OCTET_ARRAY_TYPE:
-			(void)memcpy(outP,pData->paramData,pData->paramSpec.paramLeng);
-			temp = pData->paramSpec.paramLeng;
-			break;
-		case RPC_STRING_TYPE:
-			(void)memcpy(outP,pData->paramData,pData->paramSpec.paramLeng);
-			((uint8_t*)outP)[pData->paramSpec.paramLeng] = 0;
-			temp = pData->paramSpec.paramLeng+1;
-			break;
-		case RPC_TYPE_UNKNOWN:
-			temp = pData->paramSpec.paramLeng;
-			break;
-		default:
-			break;
+		if((ret = IPC_putMarshalledData(pData,outP,&leng)) != RPC_SUCCESS) {
+			IPC_FreeShmMem(IpcMarshalDataSharedMemId, inData);
+			(void)RPC_LogPrint(RPC_LOG_MODULE_MARSHAL,RPC_LOG_LEVEL_ERROR,"FAIL IN IPC_Unmarshal");
+			return ret;
 		}
-#endif	/* RPC_CHECK_BYTEORDER */
-		if(temp > 0)
+		if(leng > 0)
 			pData->paramData = outP;
 		else
 			pData->paramData = (uint8_t*)NULL;
-		outP = (void*)&(((uint8_t*)outP)[IPC_ALIGNMENT(temp)]);
-		oSize -= IPC_ALIGNMENT(temp);
+		outP = (void*)&(((uint8_t*)outP)[IPC_ALIGNMENT(leng)]);
+		oSize -= IPC_ALIGNMENT(leng);
 	}
 //	(void)RPC_LogPrint(RPC_LOG_MODULE_MARSHAL, RPC_LOG_LEVEL_DEBUG2, "  FREE MEM inData:0x%x;",inData);
 	IPC_FreeShmMem(IpcMarshalDataSharedMemId, inData);
@@ -304,16 +289,20 @@ extern void IPC_SetMsgParam(RpcMsgParam_t *msgParam,uint32_t funcId,uint32_t pId
 /* ----- Internal Functions ----- */
 
 static RpcResult_t IPC_parseOneData(RpcParamData_t *inData,uint32_t *useSize) {
-	uint32_t enableLength;
+	uint32_t enableLength;uint32_t leng;
 
 	*useSize = sizeof(RpcParamSpec_t);
+	leng = inData->paramSpec.paramLeng;
 	switch(inData->paramSpec.paramType) {
 	case RPC_INT_TYPE:
-		enableLength = IPC_ENABLE_INT_TYPE_LENGTH; break;
+		enableLength = IPC_ENABLE_INT_TYPE_LENGTH;
+		break;
 	case RPC_UINT_TYPE:
-		enableLength = IPC_ENABLE_UINT_TYPE_LENGTH; break;
+		enableLength = IPC_ENABLE_UINT_TYPE_LENGTH;
+		break;
 	case RPC_FLOAT_TYPE:
-		enableLength = IPC_ENABLE_FLOAT_TYPE_LENGTH; break;
+		enableLength = IPC_ENABLE_FLOAT_TYPE_LENGTH;
+		break;
 	case RPC_STRING_TYPE:
 		enableLength = IPC_ENABLE_STRING_TYPE_LENGTH;
 		if(strlen(inData->paramData) != inData->paramSpec.paramLeng) {
@@ -322,24 +311,43 @@ static RpcResult_t IPC_parseOneData(RpcParamData_t *inData,uint32_t *useSize) {
 		}
 		break;
 	case RPC_ENUM_TYPE:
-		enableLength = IPC_ENABLE_ENUM_TYPE_LENGTH; break;
+		enableLength = IPC_ENABLE_ENUM_TYPE_LENGTH;
+		break;
 	case RPC_OCTET_ARRAY_TYPE:
-		enableLength = IPC_ENABLE_OCTET_ARRAY_TYPE_LENGTH; break;
+		enableLength = IPC_ENABLE_OCTET_ARRAY_TYPE_LENGTH;
+		break;
 	case RPC_TYPE_UNKNOWN:
-		enableLength = IPC_ENABLE_UNKNOWN_TYPE_LENGTH; break;
+		enableLength = IPC_ENABLE_UNKNOWN_TYPE_LENGTH;
+		break;
 	case RPC_BOOLEAN_TYPE:
-		enableLength = IPC_ENABLE_BOOLEAN_TYPE_LENGTH; break;
+		enableLength = IPC_ENABLE_BOOLEAN_TYPE_LENGTH;
+		leng = IPC_LENGTH_OF_BOOLEAN_TYPE;
+		break;
 	case RPC_REFERENCE_TYPE:
-		enableLength = IPC_ENABLE_REFERENCE_TYPE_LENGTH; break;
+#ifndef	USE_IDC
+		if(sizeof(uint8_t*) != inData->paramSpec.paramLeng) {
+			*useSize = 0;
+			return (RPC_PARAM_ERROR);
+		}
+		leng = IPC_LENGTH_OF_ADDR_OF_REFERENCE_TYPE;
+#else	/* USE_IDC */
+		(void)RPC_LogPrint(RPC_LOG_MODULE_MARSHAL,RPC_LOG_LEVEL_WARNING,"THIS SYSTEM DOES STILL NOT SUPPORT DEVICE ID IN MARSHALLING REFERENCE TYPE");
+		if(sizeof(uint8_t*) != inData->paramSpec.paramLeng) {
+			*useSize = 0;
+			return (RPC_PARAM_ERROR);
+		}
+		leng = IPC_LENGTH_OF_ADDR_OF_REFERENCE_TYPE+IPC_LENGTH_OF_DEVID_OF_REFERENCE_TYPE;
+#endif	/*USE_IDC */
+		break;
 	default:
 		*useSize = 0;
 		return (RPC_PARAM_ERROR);
 	}
-	if(IPC_checkParamLength(inData->paramSpec.paramLeng,enableLength) != RPC_SUCCESS) {
+	if(IPC_checkParamLength(leng,enableLength) != RPC_SUCCESS) {
 		*useSize = 0;
 		return RPC_PARAM_ERROR;
 	}
-	*useSize += IPC_ALIGNMENT(inData->paramSpec.paramLeng);
+	*useSize += IPC_ALIGNMENT(leng);
 	return RPC_SUCCESS;
 }
 
@@ -357,7 +365,8 @@ static RpcResult_t IPC_checkParamLength(uint32_t paramLeng,uint32_t enableLeng)
 
 static RpcResult_t IPC_putOneData(RpcParamData_t *inData,void *outData,uint32_t outSize,uint32_t *useSize) {
 	RpcResult_t ret = RPC_SUCCESS;
-	RpcParamSpec_t *paramSpec;void *dataP;int rest;
+	RpcParamSpec_t *paramSpec;void *dataP;int rest;uint32_t leng;
+	uint8_t tempVal;uint64_t tempRef;
 
 //	(void)RPC_LogPrint(RPC_LOG_MODULE_MARSHAL,RPC_LOG_LEVEL_DEBUG2,"IN IPC_putOneData inData:0x%x;(TYPE:0x%x; LENG:%d; DATA:0x%x;) outData:0x%x;, outSize:%d; useSize:0x%x;",
 //		     inData,inData->paramSpec.paramType,inData->paramSpec.paramLeng,inData->paramData,outData,outSize,useSize);
@@ -369,6 +378,7 @@ static RpcResult_t IPC_putOneData(RpcParamData_t *inData,void *outData,uint32_t
 	paramSpec = (RpcParamSpec_t*)outData;
 	*useSize = sizeof(RpcParamSpec_t);
 	dataP = (void*)&(((uint8_t*)outData)[*useSize]);
+	leng = inData->paramSpec.paramLeng;
 	switch(inData->paramSpec.paramType) {
 	case RPC_INT_TYPE:
 	case RPC_UINT_TYPE:
@@ -377,47 +387,116 @@ static RpcResult_t IPC_putOneData(RpcParamData_t *inData,void *outData,uint32_t
 	case RPC_ENUM_TYPE:
 	case RPC_OCTET_ARRAY_TYPE:
 	case RPC_TYPE_UNKNOWN:
-	case RPC_BOOLEAN_TYPE:
-	case RPC_REFERENCE_TYPE:
 #ifndef	RPC_CHECK_BYTEORDER
 		paramSpec->paramType = inData->paramSpec.paramType;
-		paramSpec->paramLeng = inData->paramSpec.paramLeng;
+		paramSpec->paramLeng = leng;
 #else	/* RPC_CHECK_BYTEORDER */
 		IPC_convertNetworkByteOrder((void*)&(inData->paramSpec.paramType),(void*)&(paramSpec->paramType),sizeof(inData->paramSpec.paramType));
-		IPC_convertNetworkByteOrder((void*)&(inData->paramSpec.paramLeng),(void*)&(paramSpec->paramLeng),sizeof(inData->paramSpec.paramLeng));
+		IPC_convertNetworkByteOrder((void*)&(leng),(void*)&(paramSpec->paramLeng),sizeof(leng));
 #endif	/* RPC_CHECK_BYTEORDER */
-		if((inData->paramSpec.paramLeng > 0)&&(outSize < (*useSize + IPC_ALIGNMENT(inData->paramSpec.paramLeng)))) {
-			ret = RPC_NO_MORE_RESOURCE;
-			goto errOut;
-		}
+		break;
+	case RPC_BOOLEAN_TYPE:
+		leng = IPC_LENGTH_OF_BOOLEAN_TYPE;
+#ifndef	RPC_CHECK_BYTEORDER
+		paramSpec->paramType = inData->paramSpec.paramType;
+		paramSpec->paramLeng = leng;
+#else	/* RPC_CHECK_BYTEORDER */
+		IPC_convertNetworkByteOrder((void*)&(inData->paramSpec.paramType),(void*)&(paramSpec->paramType),sizeof(inData->paramSpec.paramType));
+		IPC_convertNetworkByteOrder((void*)&(leng),(void*)&(paramSpec->paramLeng),sizeof(leng));
+#endif	/* RPC_CHECK_BYTEORDER */
+		break;
+	case RPC_REFERENCE_TYPE:
+#ifndef	USE_IDC
+		leng = IPC_LENGTH_OF_ADDR_OF_REFERENCE_TYPE;
+#ifndef	RPC_CHECK_BYTEORDER
+		paramSpec->paramType = inData->paramSpec.paramType;
+		paramSpec->paramLeng = leng;
+#else	/* RPC_CHECK_BYTEORDER */
+		IPC_convertNetworkByteOrder((void*)&(inData->paramSpec.paramType),(void*)&(paramSpec->paramType),sizeof(inData->paramSpec.paramType));
+		IPC_convertNetworkByteOrder((void*)&(leng),(void*)&(paramSpec->paramLeng),sizeof(leng));
+#endif	/* RPC_CHECK_BYTEORDER */
+#else	/* USE_IDC */
+		leng = IPC_LENGTH_OF_ADDR_OF_REFERENCE_TYPE+IPC_LENGTH_OF_DEVID_OF_REFERENCE_TYPE;
+#ifndef	RPC_CHECK_BYTEORDER
+		paramSpec->paramType = inData->paramSpec.paramType;
+		paramSpec->paramLeng = leng;
+#else	/* RPC_CHECK_BYTEORDER */
+		IPC_convertNetworkByteOrder((void*)&(inData->paramSpec.paramType),(void*)&(paramSpec->paramType),sizeof(inData->paramSpec.paramType));
+		IPC_convertNetworkByteOrder((void*)&(leng),(void*)&(paramSpec->paramLeng),sizeof(leng));
+#endif	/* RPC_CHECK_BYTEORDER */
+#endif	/* USE_IDC */
 		break;
 	default:
 		ret = RPC_PARAM_ERROR;
 		goto errOut;
 	}
-	if(inData->paramSpec.paramLeng > 0) {
-		*useSize += inData->paramSpec.paramLeng;
-#ifndef	RPC_CHECK_BYTEORDER
-		(void)memcpy(dataP,(void*)inData->paramData,inData->paramSpec.paramLeng);
-#else	/* RPC_CHECK_BYTEORDER */
+	if((leng > 0)&&(outSize < (*useSize + IPC_ALIGNMENT(leng)))) {
+		ret = RPC_NO_MORE_RESOURCE;
+		goto errOut;
+	}
+	if(leng > 0) {
+		*useSize += leng;
 		switch(inData->paramSpec.paramType) {
 		case RPC_INT_TYPE:
 		case RPC_UINT_TYPE:
 		case RPC_FLOAT_TYPE:
 		case RPC_ENUM_TYPE:
-		case RPC_BOOLEAN_TYPE:
-		case RPC_REFERENCE_TYPE:
-			IPC_convertNetworkByteOrder((void*)inData->paramData,(void*)dataP,inData->paramSpec.paramLeng);
+#ifndef	RPC_CHECK_BYTEORDER
+			(void)memcpy(dataP,(void*)inData->paramData,leng);
+#else	/* RPC_CHECK_BYTEORDER */
+			IPC_convertNetworkByteOrder((void*)inData->paramData,(void*)dataP,leng);
+#endif	/* RPC_CHECK_BYTEORDER */
 			break;
 		case RPC_STRING_TYPE:
 		case RPC_OCTET_ARRAY_TYPE:
-			(void)memcpy(dataP,(void*)inData->paramData,inData->paramSpec.paramLeng);
+			(void)memcpy(dataP,(void*)inData->paramData,leng);
+			break;
+		case RPC_BOOLEAN_TYPE:
+			switch(*(RpcBool_t*)(inData->paramData)) {
+			case RPC_TRUE:
+				tempVal = IPC_TRUE_VAL_OF_BOOLEAN_TYPE; break;
+			case RPC_FALSE:
+				tempVal = IPC_FALSE_VAL_OF_BOOLEAN_TYPE; break;
+			default:
+				ret = RPC_PARAM_ERROR;
+				goto errOut;
+			}
+#ifndef	RPC_CHECK_BYTEORDER
+			(void)memcpy(dataP,(void*)&tempVal,leng);
+#else	/* RPC_CHECK_BYTEORDER */
+			IPC_convertNetworkByteOrder((void*)&tempVal,(void*)dataP,leng);
+#endif	/* RPC_CHECK_BYTEORDER */
+			break;
+		case RPC_REFERENCE_TYPE:
+			switch(sizeof(uint8_t*)) {
+			case 4:
+				tempRef = ((uint64_t)(*((uint32_t*)(inData->paramData)))&0x00000000FFFFFFFF);
+				break;
+			case 8:
+				tempRef = (uint64_t)(*((uint64_t*)(inData->paramData)));
+				break;
+			}
+//			(void)RPC_LogPrint(RPC_LOG_MODULE_MARSHAL,RPC_LOG_LEVEL_DEBUG3,"  INDATA:0x%x; OUTDATA:0x%Lx",
+//				*((uint32_t*)inData->paramData),tempRef);
+#ifdef	USE_IDC
+			(void)memset((void*)dataP,0,IPC_LENGTH_OF_DEVID_OF_REFERENCE_TYPE);
+#ifndef	RPC_CHECK_BYTEORDER
+			(void)memcpy((void*)((uint8_t*)dataP+IPC_LENGTH_OF_DEVID_OF_REFERENCE_TYPE),(void*)&tempRef,leng-IPC_LENGTH_OF_DEVID_OF_REFERENCE_TYPE);
+#else	/* RPC_CHECK_BYTEORDER */
+			IPC_convertNetworkByteOrder((void*)&tempRef,(void*)((uint8_t*)dataP+IPC_LENGTH_OF_DEVID_OF_REFERENCE_TYPE),leng-IPC_LENGTH_OF_DEVID_OF_REFERENCE_TYPE);
+#endif	/* RPC_CHECK_BYTEORDER */
+#else	/* USE_IDC */
+#ifndef	RPC_CHECK_BYTEORDER
+			(void)memcpy(dataP,(void*)&tempRef,leng);
+#else	/* RPC_CHECK_BYTEORDER */
+			IPC_convertNetworkByteOrder((void*)&tempRef,(void*)dataP,leng);
+#endif	/* RPC_CHECK_BYTEORDER */
+#endif	/* USE_IDC */
 			break;
 		default:
 			break;
 		}
-#endif	/* RPC_CHECK_BYTEORDER */
-		rest = IPC_ALIGNMENT(inData->paramSpec.paramLeng) - inData->paramSpec.paramLeng;
+		rest = IPC_ALIGNMENT(leng) - leng;
 		if(rest > 0) {
 			dataP = (void*)&(((uint8_t*)outData)[*useSize]);
 			(void)memset(dataP,0,rest);
@@ -433,48 +512,55 @@ errOut:
 static RpcResult_t IPC_parseMarshaledData(void *inData,uint32_t inSize,uint32_t *needSize,RpcParamData_t *pData) {
 	RpcResult_t ret = RPC_SUCCESS;RpcParamSpec_t *pSpec;
 	uint32_t enableLength;uint32_t temp;
+//	uint32_t leng;
 
-//	(void)RPC_LogPrint(RPC_LOG_MODULE_MARSHAL, RPC_LOG_LEVEL_DEBUG1, "STEP1");
+//	(void)RPC_LogPrint(RPC_LOG_MODULE_MARSHAL, RPC_LOG_LEVEL_DEBUG2, "IN IPC_parseMarshaledData inData:0x%x; inSize:%d;",
+//		inData,inSize);
+//	(void)RPC_LogPrint(RPC_LOG_MODULE_MARSHAL, RPC_LOG_LEVEL_DEBUG3, "STEP1");
 	if(inSize < sizeof(RpcParamSpec_t)) {
 		*needSize = 0;
 		return RPC_PARAM_ERROR;
 	}
-//	(void)RPC_LogPrint(RPC_LOG_MODULE_MARSHAL, RPC_LOG_LEVEL_DEBUG1, "STEP2");
+//	(void)RPC_LogPrint(RPC_LOG_MODULE_MARSHAL, RPC_LOG_LEVEL_DEBUG3, "STEP2");
 	pSpec = (RpcParamSpec_t*)inData;
 #ifdef	RPC_CHECK_BYTEORDER
 	IPC_convertHostByteOrder((void*)&(pSpec->paramType),(void*)&temp,sizeof(pSpec->paramType));
 	pSpec->paramType = temp;
-	IPC_convertHostByteOrder((void*)&(pSpec->paramLeng),(void*)&temp,sizeof(pSpec->paramType));
+	IPC_convertHostByteOrder((void*)&(pSpec->paramLeng),(void*)&temp,sizeof(pSpec->paramLeng));
 	pSpec->paramLeng = temp;
 #endif	/* RPC_CHECK_BYTEORDER */
+//	leng = pSpec->paramLeng;
 	switch(pSpec->paramType) {
 	case RPC_INT_TYPE:
 		enableLength = IPC_ENABLE_INT_TYPE_LENGTH;
-		temp = pSpec->paramLeng; break;
+		break;
 	case RPC_UINT_TYPE:
 		enableLength = IPC_ENABLE_UINT_TYPE_LENGTH;
-		temp = pSpec->paramLeng; break;
+		break;
 	case RPC_FLOAT_TYPE:
 		enableLength = IPC_ENABLE_FLOAT_TYPE_LENGTH;
-		temp = pSpec->paramLeng; break;
+		break;
 	case RPC_STRING_TYPE:
 		enableLength = IPC_ENABLE_STRING_TYPE_LENGTH;
-		temp = pSpec->paramLeng+1; break;
+//		leng = pSpec->paramLeng+1;
+		break;
 	case RPC_ENUM_TYPE:
 		enableLength = IPC_ENABLE_ENUM_TYPE_LENGTH;
-		temp = pSpec->paramLeng; break;
+		break;
 	case RPC_OCTET_ARRAY_TYPE:
 		enableLength = IPC_ENABLE_OCTET_ARRAY_TYPE_LENGTH;
-		temp = pSpec->paramLeng; break;
+		break;
 	case RPC_TYPE_UNKNOWN:
 		enableLength = IPC_ENABLE_UNKNOWN_TYPE_LENGTH;
-		temp = pSpec->paramLeng; break;
+		break;
 	case RPC_BOOLEAN_TYPE:
 		enableLength = IPC_ENABLE_BOOLEAN_TYPE_LENGTH;
-		temp = pSpec->paramLeng; break;
+//		leng = sizeof(RpcBool_t);
+		break;
 	case RPC_REFERENCE_TYPE:
 		enableLength = IPC_ENABLE_REFERENCE_TYPE_LENGTH;
-		temp = pSpec->paramLeng; break;
+//		leng = sizeof(uint8_t*);
+		break;
 	default:
 		*needSize = 0;
 		return RPC_PARAM_ERROR;
@@ -483,19 +569,77 @@ static RpcResult_t IPC_parseMarshaledData(void *inData,uint32_t inSize,uint32_t
 		*needSize = 0;
 		return RPC_PARAM_ERROR;
 	}
-//	(void)RPC_LogPrint(RPC_LOG_MODULE_MARSHAL, RPC_LOG_LEVEL_DEBUG1, "TYPE:%s",IPC_ConvertTypeToString(pSpec->paramType));
+//	(void)RPC_LogPrint(RPC_LOG_MODULE_MARSHAL, RPC_LOG_LEVEL_DEBUG3, "  TYPE:%s",IPC_ConvertTypeToString(pSpec->paramType));
 	(void)memcpy((void*)pData,(void*)pSpec,sizeof(RpcParamSpec_t));
-	*needSize = sizeof(RpcParamSpec_t) + IPC_ALIGNMENT(temp);
-//	(void)RPC_LogPrint(RPC_LOG_MODULE_MARSHAL, RPC_LOG_LEVEL_DEBUG1, "inSize:%d; NeedSize:%d TYPE:%s; LENG:%d;",inSize,*needSize,IPC_ConvertTypeToString(pData->paramSpec.paramType),pData->paramSpec.paramLeng);
+	*needSize = sizeof(RpcParamSpec_t) + IPC_ALIGNMENT(pSpec->paramLeng);
+//	(void)RPC_LogPrint(RPC_LOG_MODULE_MARSHAL, RPC_LOG_LEVEL_DEBUG3, "  inSize:%d; NeedSize:%d TYPE:%s; LENG:%d;",inSize,*needSize,IPC_ConvertTypeToString(pData->paramSpec.paramType),pData->paramSpec.paramLeng);
 	if(inSize < *needSize) {
 		*needSize = 0;
 		return RPC_PARAM_ERROR;
 	}
 	pData->paramData = (void*)&(((uint8_t*)inData)[sizeof(RpcParamSpec_t)]);
-//	(void)RPC_LogPrint(RPC_LOG_MODULE_MARSHAL, RPC_LOG_LEVEL_DEBUG1, "paramData:0x%x",pData->paramData);
+//	(void)RPC_LogPrint(RPC_LOG_MODULE_MARSHAL, RPC_LOG_LEVEL_DEBUG2, "OUT IPC_parseMarshaledData paramData:0x%x",pData->paramData);
 	return ret;
 }
 
+static RpcResult_t IPC_putMarshalledData(RpcParamData_t *pData,void *outP,uint32_t *leng) {
+	RpcBool_t tempVal;uint8_t *tempP;
+
+	*leng = 0;
+	switch(pData->paramSpec.paramType) {
+	case RPC_INT_TYPE:
+	case RPC_UINT_TYPE:
+	case RPC_ENUM_TYPE:
+	case RPC_FLOAT_TYPE:
+#ifndef	RPC_CHECK_BYTEORDER
+		(void)memcpy(outP,pData->paramData,pData->paramSpec.paramLeng);
+#else	/* RPC_CHECK_BYTEORDER */
+		IPC_convertHostByteOrder((void*)pData->paramData,(void*)outP,pData->paramSpec.paramLeng);
+#endif	/* RPC_CHECK_BYTEORDER */
+		*leng = pData->paramSpec.paramLeng;
+		break;
+	case RPC_OCTET_ARRAY_TYPE:
+		(void)memcpy(outP,pData->paramData,pData->paramSpec.paramLeng);
+		*leng = pData->paramSpec.paramLeng;
+		break;
+	case RPC_STRING_TYPE:
+		(void)memcpy(outP,pData->paramData,pData->paramSpec.paramLeng);
+		((uint8_t*)outP)[pData->paramSpec.paramLeng] = 0;
+		*leng = pData->paramSpec.paramLeng+1;
+		break;
+	case RPC_TYPE_UNKNOWN:
+		*leng = pData->paramSpec.paramLeng;
+		break;
+	case RPC_BOOLEAN_TYPE:
+		pData->paramSpec.paramLeng = *leng = sizeof(RpcBool_t);
+		switch(*(uint8_t*)(pData->paramData)) {
+		case IPC_TRUE_VAL_OF_BOOLEAN_TYPE:
+			tempVal = RPC_TRUE; break;
+		case IPC_FALSE_VAL_OF_BOOLEAN_TYPE:
+			tempVal = RPC_FALSE; break;
+		}
+		(void)memcpy(outP,(void*)&tempVal,*leng);
+		break;
+	case RPC_REFERENCE_TYPE:
+		(void)RPC_LogPrint(RPC_LOG_MODULE_MARSHAL,RPC_LOG_LEVEL_WARNING,"THIS SYSTEM DOES STILL NOT SUPPORT DEVICE ID IN UNMARSHALLING REFERENCE TYPE");
+		pData->paramSpec.paramLeng = *leng = sizeof(uint8_t*);
+#ifndef	USE_IDC
+		tempP = (uint8_t*)((uint8_t*)(pData->paramData)+(IPC_LENGTH_OF_ADDR_OF_REFERENCE_TYPE-*leng));
+#else	/* USE_IDC */
+		tempP = (uint8_t*)((uint8_t*)(pData->paramData)+(IPC_LENGTH_OF_DEVID_OF_REFERENCE_TYPE+IPC_LENGTH_OF_ADDR_OF_REFERENCE_TYPE-*leng));
+#endif	/* USE_IDC */
+#ifndef	RPC_CHECK_BYTEORDER
+		(void)memcpy(outP,tempP,*leng);
+#else	/* RPC_CHECK_BYTEORDER */
+		IPC_convertHostByteOrder((void*)tempP,(void*)outP,*leng);
+#endif	/* RPC_CHECK_BYTEORDER */
+		break;
+	default:
+		break;
+	}
+	return RPC_SUCCESS;
+}
+
 #ifdef	RPC_CHECK_BYTEORDER
 static void IPC_convertNetworkByteOrder(void *inData,void *outData,uint32_t size) {
 //	(void)RPC_LogPrint(RPC_LOG_MODULE_MARSHAL, RPC_LOG_LEVEL_DEBUG3, "IN IPC_convertNetworkByteOrder inData:0x%x; outData:0x%x; size:%d;",inData,outData,size);
@@ -609,10 +753,18 @@ uint8_t *IPC_ConvertTypeToString(RpcParamType_t type) {
 void IPC_DumpParamData(RpcParamData_t *pData) {
 	int i;char lData[128];
 
+#if	__WORDSIZE == 64
+	fprintf(stdout,"--- PARAM DATA DATA:0x%Lx ---\n",(uint64_t)pData);
+#else	/* __WORDSIZE */
 	fprintf(stdout,"--- PARAM DATA DATA:0x%x ---\n",(uint32_t)pData);
+#endif	/* __WORDSIZE */
 	i = 1;
 	while(pData->paramSpec.paramType != RPC_TYPE_UNKNOWN) {
+#if	__WORDSIZE == 64
+		fprintf(stdout," TYPE:%s LENG:%d DATA-P:0x%Lx\n",(char*)IPC_ConvertTypeToString(pData->paramSpec.paramType),pData->paramSpec.paramLeng,(uint64_t)pData->paramData);
+#else	/* __WORDSIZE */
 		fprintf(stdout," TYPE:%s LENG:%d DATA-P:0x%x\n",(char*)IPC_ConvertTypeToString(pData->paramSpec.paramType),pData->paramSpec.paramLeng,(uint32_t)pData->paramData);
+#endif	/* __WORDSIZE */
 		sprintf(lData,"NUM:%d; TYPE:%s",i,IPC_ConvertTypeToString(pData->paramSpec.paramType));
 		RPC_MemDump(pData->paramData,pData->paramSpec.paramLeng,lData);
 		switch(pData->paramSpec.paramType) {
@@ -682,7 +834,11 @@ void IPC_DumpParamData(RpcParamData_t *pData) {
 		}
 		pData++;i++;
 	}
+#if	__WORDSIZE == 64
+	fprintf(stdout," TYPE:%s LENG:%d DATA-P:0x%Lx\n",(char*)IPC_ConvertTypeToString(pData->paramSpec.paramType),pData->paramSpec.paramLeng,(uint64_t)pData->paramData);
+#else	/* __WORDSIZE */
 	fprintf(stdout," TYPE:%s LENG:%d DATA-P:0x%x\n",(char*)IPC_ConvertTypeToString(pData->paramSpec.paramType),pData->paramSpec.paramLeng,(uint32_t)pData->paramData);
+#endif	/* __WORDSIZE */
 	sprintf(lData,"NUM:%d; TYPE:%s",i,IPC_ConvertTypeToString(pData->paramSpec.paramType));
 	RPC_MemDump(pData->paramData,pData->paramSpec.paramLeng,lData);
 }
@@ -702,8 +858,7 @@ RpcResult_t marshalTest(void) {
 	char *data6 = "abcdefghijklmn";
 	RpcParamType_t data7 = RPC_ENUM_TYPE;
 	uint8_t data8[128] = {0};
-//	uint8_t *data9;
-	uint8_t data9[8];uint8_t *data9P;uint64_t data9Temp;
+	uint8_t *data9;
 	uint32_t unmarshalData[10*1024];
 	RpcBool_t data10 = RPC_TRUE;
 	RpcBool_t data11 = RPC_FALSE;
@@ -753,18 +908,17 @@ RpcResult_t marshalTest(void) {
 		(void)IPC_DestroySharedMem();
 		return RPC_FATAL_ERROR;			
 	}
+#if	__WORDSIZE == 64
+	fprintf(stdout,"@@@ SET DATA0 shmData:0x%Lx; @@@\n",(uint64_t)shmData);
+#else	/* __WORDSIZE */
 	fprintf(stdout,"@@@ SET DATA0 shmData:0x%x; @@@\n",(uint32_t)shmData);
+#endif	/* __WORDSIZE */
 	for(i = 0;i < 128;i++) {
 		data8[i] = 128 -i;
 	}
-	data9Temp = (uint64_t)((uint8_t*)shmData)&0x00000000FFFFFFFF;
-	for(i = 0;i < 8;i++) {
-		data9[i] = (uint8_t)(data9Temp>>(i*8));
-	}
-//	data9 = (uint8_t*)shmData;
-	data9P = shmData;
+	data9 = (uint8_t*)shmData;
 	for(i = 0;i < 2000;i++) {
-		data9P[i] = i;
+		data9[i] = (uint8_t)i;
 	}
 	fprintf(stdout,"@@@ SET DATA @@\n");
 	pData[0].paramSpec.paramType = RPC_INT_TYPE;pData[0].paramSpec.paramLeng = 1;pData[0].paramData = (uint8_t*)&data0;
@@ -776,9 +930,9 @@ RpcResult_t marshalTest(void) {
 	pData[6].paramSpec.paramType = RPC_STRING_TYPE;pData[6].paramSpec.paramLeng = strlen(data6);;pData[6].paramData = (uint8_t*)data6;
 	pData[7].paramSpec.paramType = RPC_ENUM_TYPE;pData[7].paramSpec.paramLeng = 4;pData[7].paramData = (uint8_t*)&data7;
 	pData[8].paramSpec.paramType = RPC_OCTET_ARRAY_TYPE;pData[8].paramSpec.paramLeng = 128;pData[8].paramData = (uint8_t*)data8;
-	pData[9].paramSpec.paramType = RPC_REFERENCE_TYPE;pData[9].paramSpec.paramLeng = 8;pData[9].paramData = (uint8_t*)&data9;
-	pData[10].paramSpec.paramType = RPC_BOOLEAN_TYPE;pData[10].paramSpec.paramLeng = 1;pData[10].paramData = (uint8_t*)&data10;
-	pData[11].paramSpec.paramType = RPC_BOOLEAN_TYPE;pData[11].paramSpec.paramLeng = 1;pData[11].paramData = (uint8_t*)&data11;
+	pData[9].paramSpec.paramType = RPC_REFERENCE_TYPE;pData[9].paramSpec.paramLeng = sizeof(uint8_t*);pData[9].paramData = (uint8_t*)&data9;
+	pData[10].paramSpec.paramType = RPC_BOOLEAN_TYPE;pData[10].paramSpec.paramLeng = sizeof(RpcBool_t);pData[10].paramData = (uint8_t*)&data10;
+	pData[11].paramSpec.paramType = RPC_BOOLEAN_TYPE;pData[11].paramSpec.paramLeng = sizeof(RpcBool_t);pData[11].paramData = (uint8_t*)&data11;
 #ifdef	IEEE754_LONG_DOUBLE_BIAS
 	pData[12].paramSpec.paramType = RPC_FLOAT_TYPE;pData[12].paramSpec.paramLeng = 16;
 	pData[12].paramData = (uint8_t*)&data12;
@@ -789,11 +943,10 @@ RpcResult_t marshalTest(void) {
 	pData[13].paramSpec.paramType = RPC_TYPE_UNKNOWN;pData[13].paramSpec.paramLeng = 0;pData[13].paramData = (uint8_t*)NULL;
 	fprintf(stdout,"\n\n@@@ BEFORE MARSHAL DATA @@@\n");
 	IPC_DumpParamData(pData);
-	RPC_MemDump((uint8_t*)(*((uint32_t*)(pData[9].paramData))),2000,"## SHM MEM DATA ##");
-
+//	RPC_MemDump((uint8_t*)(*((uint32_t*)(pData[9].paramData))),2000,"## SHM MEM DATA ##");
 
 	if((ret = IPC_Marshal(pData, (void**)&marshalData, &marshalSize)) != RPC_SUCCESS) {
-		(void)RPC_LogPrint(RPC_LOG_MODULE_MARSHAL,RPC_LOG_LEVEL_FATAL,"ERROR IN PACAKGE ret:%s;",RPC_LogConvertResultCode(ret));
+		(void)RPC_LogPrint(RPC_LOG_MODULE_MARSHAL,RPC_LOG_LEVEL_FATAL,"ERROR IN MARSHAL ret:%s;",RPC_LogConvertResultCode(ret));
 		IPC_FreeShmMem(IpcMarshalDataSharedMemId, shmData);
 		(void)IPC_DettachSharedMem();
 		(void)IPC_DestroySharedMem();
@@ -814,7 +967,7 @@ RpcResult_t marshalTest(void) {
 	fprintf(stdout,"\n\n@@@ AFTER UNMARSHAL DATA @@@\n");
 //	oData = (RpcParamData_t*)unmarshalData;
 	IPC_DumpParamData((RpcParamData_t*)unmarshalData);
-	RPC_MemDump((uint8_t*)(*((uint32_t*)((RpcParamData_t*)unmarshalData)[9].paramData)),2000,"## SHM MEM DATA ##");
+//	RPC_MemDump((uint8_t*)(*((uint32_t*)((RpcParamData_t*)unmarshalData)[9].paramData)),2000,"## SHM MEM DATA ##");
 	IPC_FreeShmMem(IpcMarshalDataSharedMemId, shmData);
 	(void)IPC_DettachSharedMem();
 	(void)IPC_DestroySharedMem();
