@@ -1125,7 +1125,7 @@ static IpcStubCBTaskResourceDBEntry_t *IPC_getIdleStubCBTaskResource(void) {
 		return (IpcStubCBTaskResourceDBEntry_t*)NULL;
 	}
 	if((entry = (IpcStubCBTaskResourceDBEntry_t*)RPC_SearchListEntryById(IpcStubRcsDBManage.stubCBTaskResourceList,(uint32_t)RPC_RESOURCE_IDLE_STATE,IPC_compareCBTaskResourceByState)) != (IpcStubCBTaskResourceDBEntry_t*)NULL) {
-		IPC_ResetTaskControl(&(entry->tskCntl));
+//		IPC_ResetTaskControl(&(entry->tskCntl));
 		(void)RPC_MutexUnlock(&(IpcStubDataManage.mutexId));
 		return entry;
 	}
@@ -1866,7 +1866,7 @@ static IpcStubMltcstResourceDBEntry_t *IPC_getIdleStubMltcstResource(void) {
 
 //	(void)RPC_LogPrint(RPC_LOG_MODULE_MLTCST,RPC_LOG_LEVEL_DEBUG2,"IN IPC_getIdleStubMltcstResource");
 	if((entry = (IpcStubMltcstResourceDBEntry_t*)RPC_SearchListEntryById(IpcStubRcsDBManage.stubMltcstResourceList,(uint32_t)RPC_RESOURCE_IDLE_STATE,IPC_compareMltcstResourceByState)) != (IpcStubMltcstResourceDBEntry_t*)NULL) {
-		IPC_ResetTaskControl(&(entry->tskCntl));
+//		IPC_ResetTaskControl(&(entry->tskCntl));
 //		(void)RPC_LogPrint(RPC_LOG_MODULE_MLTCST,RPC_LOG_LEVEL_DEBUG2,"OUT IPC_getIdleStubMltcstResource ALLOC RCS:0x%x;",entry);
 		return entry;
 	}
