@@ -46,12 +46,12 @@ static void RPC_convertErrno(int num, uint32_t *errCode);
 
 /*--- Task APIs ---*/
 
-extern RpcResult_t RPC_CreateTask(RpcTaskID_t *taskID, RpcTaskAttribute_t *taskAttr, RPC_TaskStartRoutine_t startRoutine, void *arg) {
+extern RpcResult_t RPC_CreateTask(RpcTaskID_t *taskId, RpcTaskAttribute_t *taskAttr, RPC_TaskStartRoutine_t startRoutine, void *arg) {
 	int err; RpcResult_t ret;
 
-	if((err = pthread_create((pthread_t*)taskID, (pthread_attr_t*)taskAttr, startRoutine, arg)) != 0) {
+	if((err = pthread_create((pthread_t*)taskId, (pthread_attr_t*)taskAttr, startRoutine, arg)) != 0) {
 		RPC_convertErrCode(err,&ret);
-//		*taskID = 0;
+//		*taskId = 0;
 		return ret;
 	}
 	return RPC_SUCCESS;
@@ -61,10 +61,10 @@ extern void RPC_ExitTask(void *retVal) {
 	pthread_exit(retVal);
 }
 
-extern RpcResult_t RPC_JoinTask(RpcTaskID_t taskID, void **retVal) {
+extern RpcResult_t RPC_JoinTask(RpcTaskID_t taskId, void **retVal) {
 	RpcResult_t ret;int err;
 
-	if((err = pthread_join((pthread_t)taskID,retVal)) != 0) {
+	if((err = pthread_join((pthread_t)taskId,retVal)) != 0) {
 //		(void)RPC_LogPrint(RPC_LOG_MODULE_SYSCALL,RPC_LOG_LEVEL_ERROR,"FAIL IN RPC_JoinTask ERR:0x%x;",err);
 		RPC_convertErrCode(err,&ret);
 		return ret;
@@ -72,20 +72,20 @@ extern RpcResult_t RPC_JoinTask(RpcTaskID_t taskID, void **retVal) {
 	return RPC_SUCCESS;
 }
 
-extern RpcResult_t RPC_DetachTask(RpcTaskID_t taskID) {
+extern RpcResult_t RPC_DetachTask(RpcTaskID_t taskId) {
 	RpcResult_t ret;int err;
 
-	if((err = pthread_detach((pthread_t)taskID)) != 0) {
+	if((err = pthread_detach((pthread_t)taskId)) != 0) {
 		RPC_convertErrCode(err,&ret);
 		return ret;
 	}
 	return RPC_SUCCESS;
 }
 
-extern RpcResult_t RPC_CancelTask(RpcTaskID_t taskID) {
+extern RpcResult_t RPC_CancelTask(RpcTaskID_t taskId) {
 	RpcResult_t ret;int err;
 
-	if((err = pthread_cancel((pthread_t)taskID)) != 0) {
+	if((err = pthread_cancel((pthread_t)taskId)) != 0) {
 		RPC_convertErrCode(err,&ret);
 		return ret;
 	}
@@ -260,7 +260,7 @@ extern RpcResult_t RPC_TaskAttrSetStackSize(RpcTaskAttribute_t *taskAttr, int st
 extern RpcResult_t RPC_TaskAttrGetStackSize(RpcTaskAttribute_t *taskAttr, int *stackSize) {
 	RpcResult_t ret;int err;
 
-	if((err = pthread_attr_getstacksize(taskAttr, stackSize)) != 0) {
+	if((err = pthread_attr_getstacksize(taskAttr, (size_t*)stackSize)) != 0) {
 		RPC_convertErrCode(err, &ret);
 		*stackSize = PTHREAD_STACK_MIN;
 		return ret;
@@ -281,7 +281,7 @@ extern RpcResult_t RPC_TaskAttrSetStack(RpcTaskAttribute_t *taskAttr, void *stac
 extern RpcResult_t RPC_TaskAttrGetStack(RpcTaskAttribute_t *taskAttr, void **stackAddr, int *stackSize) {
 	RpcResult_t ret;int err;
 
-	if((err = pthread_attr_getstack((pthread_attr_t*)taskAttr, stackAddr, stackSize)) != 0) {
+	if((err = pthread_attr_getstack((pthread_attr_t*)taskAttr, stackAddr, (size_t*)stackSize)) != 0) {
 		RPC_convertErrCode(err, &ret);
 		*stackAddr = (void*)NULL;
 		*stackSize = PTHREAD_STACK_MIN;
