@@ -159,10 +159,4 @@ typedef enum {
 	RPC_RESOURCE_MAX_STATE = 3
 } RpcResourceState_t;
 
-typedef struct _RpcListStruct_ {
-	struct _RpcListStruct_ *next;
-//	uint32_t entryId;
-	void *entry;
-} RpcList_t;
-
 #endif /* IPCTYPE_H_ */
